import Catalog from "../common/Catalog";
import { useEffect, useState } from "react";

import DataService from "../../services/DataService"

let headers = [
  {label: "name", text: "Имя"},
  {label: "music", text: "Музыка"},
  {label: "community", text: "Группы"},
  { label: "city", text: "Город" }
]
export default function CatalogUsers() {
  const url = "/users";

  const [data, setData] = useState({
    name: "",
    music: [],
    community: [],
    city: ""
  });

  const [selectedData, setSelectedData] = useState({
    music: "",
    community: ""
  });

  const [musics, setMusics] = useState([]);
  const [communities, setCommunities] = useState([]);

  useEffect(() => {
    let music;
    DataService.readAll("/musics").then(res => {
      setMusics(res)
      music = res[0].name;
    }).then(() => (
      DataService.readAll("/communities")
    )).then(res => {
      setCommunities(res)
      setSelectedData({music, community: res[0].name});
    });
  }, [])


  function handleFormChange(e) {
    console.log(e.target.value);
    setData({ ...data, [e.target.id]: e.target.value })
  }

  function handleChangeSelected(e) {
    setSelectedData({...selectedData, [e.target.id]: e.target.value});
  }

  function addMusic() {
    for(let g of data.music) {
      if(g == selectedData.music) return;
    }
    let temp = data.music.slice(0);
    temp.push(selectedData.music);
    setData({...data, music: temp});
  }

  function addCommunity() {
    for(let a of data.community) {
      if(a == selectedData.community) return;
    }
    let temp = data.community.slice(0);
    temp.push(selectedData.community);
    setData({...data, community: temp});
  }

  function deleteMusic(e) {
    let musicName = e.target.previousSibling.textContent;
    let temp = data.music.filter(x => (x != musicName));
    setData({...data, music: temp})
  }

  function deleteCommunity(e) {
    let communityName = e.target.previousSibling.textContent;
    let temp = data.community.filter(x => (x != communityName));
    setData({...data, community: temp})
  }

  function onAdd() {
    setData({name: "", music: [], community: []});
  }

  
  function onChange(data) {
    setData(data);
  }

  function validate(data) {
    if(data.name === "") return false;
    return true;
  }

  return (
    <Catalog url={url} headers={headers} data={data} onAdd={onAdd} onChange={onChange} validate={validate}>
      <div>
        <div className="mb-3">
          <label htmlFor="name" className="form-label">Название</label>
          <input
            type="text"
            value={data.name}
            id="name"
            className="form-control"
            required
            autoComplete="off"
            onChange={handleFormChange}
          />
        </div>
        <div className="mb-3">
                  <label htmlFor="city" className="form-label">Город</label>
                  <input
                    type="text"
                    value={data.city}
                    id="city"
                    className="form-control"
                    required
                    autoComplete="off"
                    onChange={handleFormChange}
                  />
                </div>
        <select
          id="music"
          className="form-select mb-3"
          required
          value={selectedData.music}
          onChange={handleChangeSelected}
        >
          <option disabled value="">Укажите музыку</option>
          {musics.map(({ name, id }) => (
            <option key={id} value={name}>{name}</option>
          ))}
        </select>
        {data.music.map(value => (
          <div className="badge bg-secondary mb-3" key={value}>
            <span>{value}</span>
            <button className="btn-close bg-danger" onClick={deleteMusic}></button>
          </div>
        ))}

        <br></br>
        <button onClick={addMusic} className="btn btn-success mb-3">Добавить музыку</button>

        <select
          id="community"
          className="form-select mb-3"
          required
          value={selectedData.community}
          onChange={handleChangeSelected}
        >
          <option disabled value="">Укажите группу</option>
          {communities.map(({ name, id }) => (
            <option key={id} value={name}>{name}</option>
          ))}
        </select>
        {data.community.map(value => (
          <div className="badge bg-secondary mb-3" key={value}>
            <span>{value}</span>
            <button className="btn-close bg-danger" onClick={deleteCommunity}></button>
          </div>
        ))}
        <br></br>
        <button onClick={addCommunity} className="btn btn-success mb-3">Добавить группу</button>
      </div>
    </Catalog>
  )
}