package ru.ulstu.is.sbapp.socialNetwork.controller;

import org.springframework.web.bind.annotation.*;
import ru.ulstu.is.sbapp.configuration.WebConfiguration;
import ru.ulstu.is.sbapp.socialNetwork.dto.CommunityDTO;
import ru.ulstu.is.sbapp.socialNetwork.services.CommunityService;

import javax.validation.Valid;
import java.util.List;

@RestController
@RequestMapping(WebConfiguration.REST_API + "/communities")
public class CommunityController {
    private final CommunityService communityService;

    public CommunityController(CommunityService communityService) {
        this.communityService = communityService;
    }

    @GetMapping("/{id}")
    public CommunityDTO getCommunity(@PathVariable Long id) {
        return new CommunityDTO(communityService.findCommunity(id));
    }

    @GetMapping("")
    public List<CommunityDTO> getCommunities() {
        return communityService.findAllCommunities().stream().map(CommunityDTO::new).toList();
    }

    @PostMapping("")
    public CommunityDTO createCommunity(@RequestBody @Valid CommunityDTO community) {
        return new CommunityDTO(communityService.addCommunity(community.getName()));
    }

    @PatchMapping("")
    public CommunityDTO updateCommunity(@PathVariable Long id, @RequestBody @Valid CommunityDTO community) {
        return new CommunityDTO(communityService.updateCommunity(id, community.getName()));
    }

    @DeleteMapping("/{id}")
    public CommunityDTO deleteCommunity(@PathVariable Long id) {
        return new CommunityDTO(communityService.deleteCommunity(id));
    }
}
